Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8308)

Unified Diff: chrome/browser/ui/views/location_bar/location_bar_view.h

Issue 2378623007: [Material] Update Material Security Verbose Decoration Flag (Closed)
Patch Set: fixed an animation error on cocoa Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/location_bar/location_bar_view.h
diff --git a/chrome/browser/ui/views/location_bar/location_bar_view.h b/chrome/browser/ui/views/location_bar/location_bar_view.h
index b20c54f74a5ad531ffffc264dcd3d527e6b9d284..612a6fd3959884ad7f58d09e019ecea4e8cd92f8 100644
--- a/chrome/browser/ui/views/location_bar/location_bar_view.h
+++ b/chrome/browser/ui/views/location_bar/location_bar_view.h
@@ -325,8 +325,10 @@ class LocationBarView : public LocationBar,
bool ShouldShowEVBubble() const;
// Returns true when the current page is explicitly secure or insecure.
- // In these cases, we should show the state of the security chip.
- bool ShouldShowSecurityChip() const;
+ // In these cases, we should show the state of the security chip. If
+ // should_animate is not null, then set the value to true if the chip should
Peter Kasting 2016/10/10 21:39:21 Nit: "...|should_animate| is non-null, sets it to
spqchan 2016/10/11 17:32:58 Updated the comment
+ // be animated.
+ bool ShouldShowSecurityChip(bool* should_animate) const;
Peter Kasting 2016/10/10 21:39:21 I think it might make more sense to have separate
Kevin Bailey 2016/10/11 00:44:05 If GetSecurityLevel() were more stable, I would co
Peter Kasting 2016/10/11 00:54:18 No. If we thought this was problematic, such that
// Used to "reverse" the URL showing/hiding animations, since we use separate
// animations whose curves are not true inverses of each other. Based on the
@@ -480,6 +482,7 @@ class LocationBarView : public LocationBar,
// These allow toggling the verbose security state behavior via flags.
bool should_show_secure_state_;
bool should_animate_secure_state_;
+ bool should_animate_nonsecure_state_;
DISALLOW_COPY_AND_ASSIGN(LocationBarView);
};

Powered by Google App Engine
This is Rietveld 408576698